@@ -1,4 +1,5 @@
-package My::Groups;
+package    #hide
+  My::Groups;
 use strict;
 use warnings;
 use utf8;
